More About Iteration
::::::::::::::::::::

.. toctree::
   :caption: More About Iteration
   :maxdepth: 2

   intro-IterationRevisited.rst
   Theforlooprevisited.rst
   ThewhileStatement.rst
   RandomlyWalkingTurtles.rst
   The3n1Sequence.rst
   NewtonsMethod.rst
   accumulatorRevisited.rst
   SentinelValuesAndValidation.rst
   AlgorithmsRevisited.rst
   SimpleTables.rst
   2DimensionalIterationImageProcessing.rst
   ImageProcessingonYourOwn.rst
   Glossary.rst
   Exercises.rst
